==> sso-api-2.3.3-sources.jar: cn/com/duiba/sso/api/web/interceptor/handler/impl/MobileLoginFilterHandler.java <==
package cn.com.duiba.sso.api.web.interceptor.handler.impl;

import cn.com.duiba.sso.api.constants.SsoProperties;
import cn.com.duiba.sso.api.domain.dto.AdminDto;
import cn.com.duiba.sso.api.exception.SsoException;
import cn.com.duiba.sso.api.remoteservice.RemoteSSOService;
import cn.com.duiba.sso.api.service.system.SsoSystemService;
import cn.com.duiba.sso.api.tool.RequestTool;
import cn.com.duiba.sso.api.tool.SystemInfo;
import cn.com.duiba.sso.api.web.interceptor.annotation.OnlyMobileHandler;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.annotation.Resource;

@OnlyMobileHandler
public class MobileLoginFilterHandler extends AbstractLoginFilterHandler {

    private static Logger logger = LoggerFactory.getLogger(MobileLoginFilterHandler.class);

    @Resource
    protected SsoProperties properties;
    @Resource
    private RemoteSSOService remoteSSOService;
    @Resource
    private SsoSystemService ssoSystemService;


    @Override
    public Boolean before(Object handler){
        String ticket = RequestTool.findMobileTicket();
        if(StringUtils.isBlank(ticket)){
            returnNotLogin();
            return false;
        }
        try{
            AdminDto admin = remoteSSOService.verifyTicketAndGetAdmin(ticket);
            if(admin==null){
                throw new SsoException("通行证失效");
            }
            //注入adminId
            RequestTool.setAdmin(admin);
            return true;
        }catch (Exception e){
            logger.info("通行证验证失败",e);
            returnNotLogin();
            return false;
        }
    }

    /**
     * 获取登录重定向地址
     * @return
     */
    @Override
    protected String getLoginRedirectUrl(){
        String redirect = getCurrentRedirect();
        StringBuilder builder = new StringBuilder();
        String loginUrl = ssoSystemService.getSsoHomeUrl() + "/mobile/emailBind";
        builder.append(loginUrl).append("?redirect=").append(redirect);
        builder.append("&systemId=").append(SystemInfo.getThisSystemId());
        return builder.toString();
    }

    @Override
    protected String getDefaultRedirectUrl(){
        return properties.getMobileDefaultRedirectUrl();
    }



}

==> sso-api-2.3.35-sources.jar: cn/com/duiba/sso/api/web/interceptor/handler/impl/MobileLoginFilterHandler.java <==
package cn.com.duiba.sso.api.web.interceptor.handler.impl;

import cn.com.duiba.sso.api.constants.SsoProperties;
import cn.com.duiba.sso.api.domain.dto.AdminDto;
import cn.com.duiba.sso.api.exception.SsoException;
import cn.com.duiba.sso.api.remoteservice.RemoteSSOService;
import cn.com.duiba.sso.api.service.system.SsoSystemService;
import cn.com.duiba.sso.api.tool.RequestTool;
import cn.com.duiba.sso.api.tool.SystemInfo;
import cn.com.duiba.sso.api.web.interceptor.annotation.MobileHandler;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.annotation.Resource;

@MobileHandler
public class MobileLoginFilterHandler extends AbstractLoginFilterHandler  {

    private static Logger logger = LoggerFactory.getLogger(MobileLoginFilterHandler.class);

    @Resource
    protected SsoProperties properties;
    @Resource
    private RemoteSSOService remoteSSOService;
    @Resource
    private SsoSystemService ssoSystemService;

    @Override
    public Boolean before(Object handler){
        String ticket = RequestTool.findMobileTicket();
        if(StringUtils.isBlank(ticket)){
            returnNotLogin();
            return false;
        }
        try{
            AdminDto admin = remoteSSOService.verifyTicketAndGetAdmin(ticket);
            if(admin==null){
                throw new SsoException("通行证失效");
            }
            //注入adminId
            RequestTool.setAdmin(admin);
            return true;
        }catch (Exception e){
            logger.info("通行证验证失败",e);
            returnNotLogin();
            return false;
        }
    }

    /**
     * 获取登录重定向地址
     */
    @Override
    protected String getLoginRedirectUrl(){
        String redirect = getCurrentRedirect();
        StringBuilder builder = new StringBuilder();
        String loginUrl = ssoSystemService.getSsoHomeUrl() + "/mobile/emailBind";
        builder.append(loginUrl).append("?redirect=").append(redirect);
        builder.append("&systemId=").append(SystemInfo.getThisSystemId());
        return builder.toString();
    }

    @Override
    protected String getDefaultRedirectUrl(){
        return properties.getMobileDefaultRedirectUrl();
    }



}
